package cz.xelfi.quoridor.webidor;

import cz.xelfi.quoridor.IllegalPositionException;
import cz.xelfi.quoridor.Move;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;

public final class CommentedMove {
    Move move;
    int index;
    List<Note> comments;

    private CommentedMove() {
        super();
    }

    CommentedMove(Move move, int index) {
        super();
        this.move = move;
        this.index = index;
    }

    public Move getMove() {
        return move;
    }

    @XmlAttribute(name="move")
    String getMoveText() {
        return move.toString();
    }

    void setMoveText(String m) throws IllegalPositionException {
        move = Move.valueOf(m);
    }
    
    @XmlAttribute
    int getIndex() {
        return index;
    }

    void setIndex(int i) {
        index = i;
    }

    void addNote(Note n) {
        if (comments == null) {
            comments = new ArrayList<Note>();
        }
        comments.add(n);
    }

    @XmlElement(name="comment", required=false)
    public final List<Note> getComments() {
        return comments;
    }

    final void setComments(List<Note> l) {
        this.comments = l;
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("Move[").append(move).append("@").append(index);
        if (comments != null) {
            sb.append(", ");
            sb.append(comments);
        }
        sb.append("]");
        return sb.toString();
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final CommentedMove other = (CommentedMove) obj;
        if (this.move != other.move && (this.move == null || !this.move.equals(other.move))) {
            return false;
        }
        if (this.index != other.index) {
            return false;
        }
        if (this.comments != other.comments && (this.comments == null || !this.comments.equals(other.comments))) {
            return false;
        }
        return true;
    }

    @Override
    public int hashCode() {
        int hash = 5;
        hash = 43 * hash + (this.move != null ? this.move.hashCode() : 0);
        hash = 43 * hash + this.index;
        hash = 43 * hash + (this.comments != null ? this.comments.hashCode() : 0);
        return hash;
    }
}
